package weaver.formmode.mzg.modeexpand.resume;

import com.engine.mzg.conn.RecruitCommon;
import com.engine.mzg.conn.RecruitRecordSet;
import com.engine.mzg.enums.EmailTemplateEnum;
import com.engine.mzg.exception.CustomizeRunTimeException;
import com.engine.mzg.util.RecruitUtil;
import com.weaver.formmodel.data.model.Formfield;
import org.apache.commons.lang3.StringUtils;
import weaver.conn.RecordSet;
import weaver.formmode.IgnoreCaseHashMap;
import weaver.formmode.customjavacode.AbstractModeExpandJavaCodeNew;
import weaver.general.BaseBean;
import weaver.general.Util;
import weaver.soa.workflow.request.MainTableInfo;
import weaver.soa.workflow.request.Property;
import weaver.soa.workflow.request.RequestInfo;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * 发送DISC性格测评
 *
 * @author:dxfeng
 * @createTime: 2024/09/05
 * @version: 1.0
 */
public class SendDiscExpand extends AbstractModeExpandJavaCodeNew {
    @Override
    public Map<String, String> doModeExpand(Map<String, Object> param) {
        Map<String, String> result = new HashMap<>();
        try {
            int billId;
            RequestInfo requestInfo = (RequestInfo) param.get("RequestInfo");
            if (requestInfo != null) {
                billId = Util.getIntValue(requestInfo.getRequestid());
                IgnoreCaseHashMap<String, String> mainDataMap = new IgnoreCaseHashMap<>();
                MainTableInfo mainTableInfo = requestInfo.getMainTableInfo();
                Property[] properties = mainTableInfo.getProperty();
                for (Property property : properties) {
                    mainDataMap.put(property.getName(), property.getValue());
                }

                RecordSet rs = new RecordSet();
                String mobileAppidDisc = RecruitCommon.getSettingValue("MOBILE_APPID_DISC");
                String mobileUrlDisc = RecruitCommon.getSettingValue("MOBILE_URL_DISC");
                String httpUrl = RecruitCommon.getSettingValue("HTTP_URL");
                rs.executeQuery("select noLoginUser from mobileappbaseinfo where id = ?", mobileAppidDisc);
                int creator = -1;
                if (rs.next()) {
                    creator = rs.getInt("noLoginUser");
                }
                if (-1 == creator) {
                    throw new CustomizeRunTimeException("未配置免登陆访问用户，请检查移动建模应用配置");
                }

                String sendTo = Util.null2String(mainDataMap.get("dzyx"));
                if (StringUtils.isBlank(sendTo)) {
                    throw new CustomizeRunTimeException("电子邮箱为空,邮件发送失败");
                }
                String emailTitle = "";
                String emailContent = "";
                rs.executeQuery("select yjzt ,yjnr  from uf_recruit_email where mblx =? ", EmailTemplateEnum.DISC.getValue());
                if (rs.next()) {
                    emailTitle = rs.getString("yjzt");
                    emailContent = rs.getString("yjnr");
                }

                if (StringUtils.isBlank(emailTitle) || StringUtils.isBlank(emailContent)) {
                    throw new CustomizeRunTimeException("请检查邮件模板设置");
                }


                // 插入DISC测评表数据
                IgnoreCaseHashMap<String, Object> dataMap = new IgnoreCaseHashMap<>();
                String uuid = UUID.randomUUID().toString();
                dataMap.put("modeuuid", uuid);
                int formModeId = RecruitCommon.getModeIdByTableName("uf_recruit_disc");
                dataMap.put("formmodeid", formModeId);
                // 构建建模表基本数据
                RecruitRecordSet.buildModeInsertFields(dataMap, creator);
                dataMap.put("xm", billId);
                dataMap.put("sqzw", mainDataMap.get("sqzw"));
                dataMap.put("lxfs", mainDataMap.get("lxfs"));

                dataMap.put("modedatastatus", "0");
                // 插入数据
                RecruitRecordSet.insertData(dataMap, "uf_recruit_disc");

                int id = RecruitRecordSet.refreshRight(uuid, "uf_recruit_disc", formModeId, creator);

                // 测评ID反写简历中心表,更新状态
                rs.executeUpdate("update uf_recruit_resume set cpzt = ? ,cpglid = ? where id = ? ", 1, id, billId);

                // 发送邮件
                // 查询字段信息
                List<Formfield> fieldList = RecruitUtil.getFieldList("uf_recruit_resume");
                Map<String, List<Formfield>> fieldMapList = fieldList.stream().collect(Collectors.groupingBy(Formfield::getFieldname));
                String url = httpUrl + mobileUrlDisc + "&billid=" + id;
                if (StringUtils.isNotBlank(url)) {
                    url = "<span><a href='" + url + "'  target='_blank'>链接地址</a></span>";
                }
                emailContent = emailContent.replace("{链接地址}", url);
                emailContent = RecruitUtil.getReplaceContent(emailContent, fieldMapList, mainDataMap);
                RecruitUtil.sendEmail(sendTo, emailTitle, emailContent);
            }
        } catch (Exception e) {
            new BaseBean().writeLog(e);
            result.put("errmsg", e.getMessage());
            result.put("flag", "false");
        }
        return result;
    }
}
